summaryrefslogtreecommitdiff
path: root/public/fpdf_edit.h
diff options
context:
space:
mode:
Diffstat (limited to 'public/fpdf_edit.h')
-rw-r--r--public/fpdf_edit.h32
1 files changed, 19 insertions, 13 deletions
diff --git a/public/fpdf_edit.h b/public/fpdf_edit.h
index 677bce80b1..e71b4edb94 100644
--- a/public/fpdf_edit.h
+++ b/public/fpdf_edit.h
@@ -440,14 +440,16 @@ FPDFPageObjMark_GetParamBlobValue(FPDF_PAGEOBJECTMARK mark,
// with key |key| exists, its value is set to |value|. Otherwise, it is added as
// a new parameter.
//
// document - handle to the document.
// mark - handle to a content mark.
// key - string key of the property.
// value - int value to set.
//
// Returns TRUE if the operation succeeded, FALSE otherwise.
FPDF_EXPORT FPDF_BOOL FPDF_CALLCONV
FPDFPageObjMark_SetIntParam(FPDF_DOCUMENT document,
+ FPDF_PAGEOBJECT page_object,
FPDF_PAGEOBJECTMARK mark,
FPDF_BYTESTRING key,
int value);
@@ -457,14 +459,16 @@ FPDFPageObjMark_SetIntParam(FPDF_DOCUMENT document,
// with key |key| exists, its value is set to |value|. Otherwise, it is added as
// a new parameter.
//
// document - handle to the document.
// mark - handle to a content mark.
// key - string key of the property.
// value - string value to set.
//
// Returns TRUE if the operation succeeded, FALSE otherwise.
FPDF_EXPORT FPDF_BOOL FPDF_CALLCONV
FPDFPageObjMark_SetStringParam(FPDF_DOCUMENT document,
+ FPDF_PAGEOBJECT page_object,
FPDF_PAGEOBJECTMARK mark,
FPDF_BYTESTRING key,
FPDF_BYTESTRING value);
@@ -474,15 +478,17 @@ FPDFPageObjMark_SetStringParam(FPDF_DOCUMENT document,
// with key |key| exists, its value is set to |value|. Otherwise, it is added as
// a new parameter.
//
// document - handle to the document.
// mark - handle to a content mark.
// key - string key of the property.
// value - pointer to blob value to set.
// value_len - size in bytes of |value|.
//
// Returns TRUE if the operation succeeded, FALSE otherwise.
FPDF_EXPORT FPDF_BOOL FPDF_CALLCONV
FPDFPageObjMark_SetBlobParam(FPDF_DOCUMENT document,
+ FPDF_PAGEOBJECT page_object,
FPDF_PAGEOBJECTMARK mark,
FPDF_BYTESTRING key,
void* value,
@@ -440,14 +440,16 @@ FPDFPageObjMark_GetParamBlobValue(FPDF_PAGEOBJECTMARK mark,
// a new parameter.
//
-// document - handle to the document.
-// mark - handle to a content mark.
-// key - string key of the property.
-// value - int value to set.
+// document - handle to the document.
+// page_object - handle to the page object with the mark.
+// mark - handle to a content mark.
+// key - string key of the property.
+// value - int value to set.
//
// Returns TRUE if the operation succeeded, FALSE otherwise.
@@ -457,14 +459,16 @@ FPDFPageObjMark_SetIntParam(FPDF_DOCUMENT document,
// a new parameter.
//
-// document - handle to the document.
-// mark - handle to a content mark.
-// key - string key of the property.
-// value - string value to set.
+// document - handle to the document.
+// page_object - handle to the page object with the mark.
+// mark - handle to a content mark.
+// key - string key of the property.
+// value - string value to set.
//
// Returns TRUE if the operation succeeded, FALSE otherwise.
@@ -474,15 +478,17 @@ FPDFPageObjMark_SetStringParam(FPDF_DOCUMENT document,
// a new parameter.
//
-// document - handle to the document.
-// mark - handle to a content mark.
-// key - string key of the property.
-// value - pointer to blob value to set.
-// value_len - size in bytes of |value|.
+// document - handle to the document.
+// page_object - handle to the page object with the mark.
+// mark - handle to a content mark.
+// key - string key of the property.
+// value - pointer to blob value to set.
+// value_len - size in bytes of |value|.
//
// Returns TRUE if the operation succeeded, FALSE otherwise.